(* Delphi Dialog
   Auswahl und Bearbeiten von Listeneintrgen
   ==========================================
   
    Dr. J. Rathlev, D-24222 Schwentinental (info(a)rathlev-home.de)

   The contents of this file may be used under the terms of the
   Mozilla Public License ("MPL") or
   GNU Lesser General Public License Version 2 or later (the "LGPL")

   Software distributed under this License is distributed on an "AS IS" basis,
   WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
   the specific language governing rights and limitations under the License.
    
   Vers. 1 - Apr. 2005
   letzte nderung - Jun. 2019
    *)

unit EditStringListDlg;

interface

uses Winapi.Windows, System.SysUtils, System.Classes, Vcl.Graphics, Vcl.Forms,
  Vcl.Controls, Vcl.StdCtrls, Vcl.Buttons, Vcl.ExtCtrls;

type
  TEditStringListDialog = class(TForm)
    OKBtn: TBitBtn;
    CancelBtn: TBitBtn;
    lbxStringList: TListBox;
    gbxMove: TGroupBox;
    UpBtn: TSpeedButton;
    DownBtn: TSpeedButton;
    lbDesc: TLabel;
    btnDelete: TBitBtn;
    procedure FormCreate(Sender: TObject);
    procedure UpBtnClick(Sender: TObject);
    procedure DownBtnClick(Sender: TObject);
    procedure btnDeleteClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  function Execute (APos : TPoint; Titel,Desc : string;
                    SList : TStrings; ADelete : boolean;
                    var AIndex : integer) : boolean;
  end;

function EditStringList(APos : TPoint; Titel,Desc : string;
                      SList : TStrings; ADelete : boolean;
                      var AIndex : integer) : boolean;

var
  EditStringListDialog: TEditStringListDialog;

implementation

{$R *.DFM}

uses InpText, WinUtils;

{------------------------------------------------------------------- }
procedure TEditStringListDialog.FormCreate(Sender: TObject);
begin
  // ***
  end;

{------------------------------------------------------------------- }
procedure TEditStringListDialog.UpBtnClick(Sender: TObject);
var
  n : integer;
begin
  with lbxStringList,Items do if (Count>0) and (ItemIndex>0) then begin
    n:=ItemIndex;
    Exchange(n,n-1);
    ItemIndex:=n-1;
    end;
  end;

procedure TEditStringListDialog.btnDeleteClick(Sender: TObject);
var
  n : integer;
begin
  with lbxStringList do if ItemIndex>=0 then begin
    n:=ItemIndex;
    Items.Delete(ItemIndex);
    if n>Items.Count then ItemIndex:=Items.Count-1 else ItemIndex:=n;
    end;
  end;

procedure TEditStringListDialog.DownBtnClick(Sender: TObject);
var
  n : integer;
begin
  with lbxStringList,Items do if (Count>0) and (ItemIndex<Count-1) then begin
    n:=ItemIndex;
    Exchange(n,n+1);
    ItemIndex:=n+1;
    end;
  end;

{------------------------------------------------------------------- }
function TEditStringListDialog.Execute (APos : TPoint; Titel,Desc : string;
                    SList : TStrings; ADelete : boolean;
                    var AIndex : integer) : boolean;
var
  i : integer;
  s : string;
begin
  with APos do begin
    if (Y < 0) or (X < 0) then Position:=poScreenCenter
    else begin
      if X<0 then X:=Left;
      if Y<0 then Y:=Top;
      CheckScreenBounds(Screen,x,y,Width,Height);
      Left:=x; Top:=y;
      end;
    end;
  if length(Titel)>0 then Caption:=Titel;
  lbDesc.Caption:=Desc;
  lbxStringList.Clear;
  btnDelete.Visible:=ADelete;
  with SList do for i:=0 to Count-1 do lbxStringList.AddItem(Strings[i],Objects[i]);
  if (AIndex>=0) and (AIndex<SList.Count) then begin
    s:=SList.Strings[AIndex];
    lbxStringList.ItemIndex:=AIndex;
    end
  else s:='';
  if ShowModal=mrOK then begin
    SList.Clear;
    with lbxStringList.Items do begin
      for i:=0 to Count-1 do SList.AddObject(Strings[i],Objects[i]);
      if length(s)>0 then begin
        i:=IndexOf(s);
        if i>=0 then AIndex:=i else AIndex:=0;
        end;
      end;
    Result:=true;
    end
  else Result:=false;
  end;

function EditStringList(APos : TPoint; Titel,Desc : string;
                        SList : TStrings; ADelete : boolean;
                        var AIndex : integer) : boolean;
begin
  if not assigned(EditStringListDialog) then begin
    EditStringListDialog:=TEditStringListDialog.Create(Application);
    end;
  Result:=EditStringListDialog.Execute(APos,Titel,Desc,SList,ADelete,AIndex);
  FreeAndNil(EditStringListDialog);
  end;

end.
